summaryrefslogtreecommitdiffstats
path: root/perl-install/printerdrake.pm
diff options
context:
space:
mode:
authorTill Kamppeter <tkamppeter@mandriva.com>2002-03-02 17:32:23 +0000
committerTill Kamppeter <tkamppeter@mandriva.com>2002-03-02 17:32:23 +0000
commit6a1610f3c99e7d772f77752769860b51248c31ae (patch)
tree8adee4deaaa9839e7ff75f69dad6748162520eee /perl-install/printerdrake.pm
parente97e40d422337b0b1b0006dfb1ff1c44f0b9718a (diff)
downloaddrakx-6a1610f3c99e7d772f77752769860b51248c31ae.tar
drakx-6a1610f3c99e7d772f77752769860b51248c31ae.tar.gz
drakx-6a1610f3c99e7d772f77752769860b51248c31ae.tar.bz2
drakx-6a1610f3c99e7d772f77752769860b51248c31ae.tar.xz
drakx-6a1610f3c99e7d772f77752769860b51248c31ae.zip
Replaced "Open Office" by "OpenOffice.org".
Diffstat (limited to 'perl-install/printerdrake.pm')
-rw-r--r--perl-install/printerdrake.pm28
1 files changed, 14 insertions, 14 deletions
diff --git a/perl-install/printerdrake.pm b/perl-install/printerdrake.pm
index ee4411654..fdb8b158c 100644
--- a/perl-install/printerdrake.pm
+++ b/perl-install/printerdrake.pm
@@ -2171,7 +2171,7 @@ sub setup_default_spooler {
return;
}
if ($printer->{SPOOLER} ne $oldspooler) {
# Remove the local printers from Star Office/Open Office
printer::removelocalprintersfromapplications($printer);
# Get the queues of this spooler
{
@@ -2373,7 +2373,7 @@ sub main {
messages =>
($noprinters ? "" :
(($printer->{SPOOLER} eq "cups") ?
- _("The following printers are configured. Double-click on a printer to change its settings; to make it the default printer; to view information about it; or to make a printer on a remote CUPS server available for Star/Open Office.") :
+ _("The following printers are configured. Double-click on a printer to change its settings; to make it the default printer; to view information about it; or to make a printer on a remote CUPS server available for Star Office/OpenOffice.org.") :
_("The following printers are configured. Double-click on a printer to change its settings; to make it the default printer; or to view information about it."))),
cancel => (""),
ok => (""),
@@ -2690,8 +2690,8 @@ What do you want to modify on this printer?",
(($queue ne $printer->{DEFAULT}) ?
_("Set this printer as the default") : ()),
($printer->{configured}{$queue} ? () :
- (_("Add this printer to Star/Open Office"),
- _("Remove this printer from Star/Open Office"))),
+ (_("Add this printer to Star Office/OpenOffice.org"),
+ _("Remove this printer from Star Office/OpenOffice.org"))),
_("Print test pages"),
_("Know how to use this printer"),
($printer->{configured}{$queue} ?
@@ -2765,23 +2765,23 @@ What do you want to modify on this printer?",
printer::set_default_printer($printer);
$in->ask_warn(_("Default printer"),
_("The printer \"%s\" is set as the default printer now.", $queue));
- } elsif ($modify eq _("Add this printer to Star/Open Office")) {
+ } elsif ($modify eq _("Add this printer to Star Office/OpenOffice.org")) {
if (printer::addcupsremotetoapplications
($printer, $queue)) {
- $in->ask_warn(_("Adding printer to Star/Open Office"),
- _("The printer \"%s\" was successfully added to Star/Open Office.", $queue));
+ $in->ask_warn(_("Adding printer to Star Office/OpenOffice.org"),
+ _("The printer \"%s\" was successfully added to Star Office/OpenOffice.org.", $queue));
} else {
- $in->ask_warn(_("Adding printer to Star/Open Office"),
- _("Failed to add the printer \"%s\" to Star/Open Office.", $queue));
+ $in->ask_warn(_("Adding printer to Star Office/OpenOffice.org"),
+ _("Failed to add the printer \"%s\" to Star Office/OpenOffice.org.", $queue));
}
- } elsif ($modify eq _("Remove this printer from Star/Open Office")) {
+ } elsif ($modify eq _("Remove this printer from Star Office/OpenOffice.org")) {
if (printer::removeprinterfromapplications
($printer, $queue)) {
- $in->ask_warn(_("Removing printer from Star/Open Office"),
- _("The printer \"%s\" was successfully removed from Star/Open Office.", $queue));
+ $in->ask_warn(_("Removing printer from Star Office/OpenOffice.org"),
+ _("The printer \"%s\" was successfully removed from Star Office/OpenOffice.org.", $queue));
} else {
- $in->ask_warn(_("Removing printer from Star/Open Office"),
- _("Failed to remove the printer \"%s\" from Star/Open Office.", $queue));
+ $in->ask_warn(_("Removing printer from Star Office/OpenOffice.org"),
+ _("Failed to remove the printer \"%s\" from Star Office/OpenOffice.org.", $queue));
}
} elsif ($modify eq _("Print test pages")) {
print_testpages($printer, $in, $upNetwork);
@@ -2171,7 +2171,7 @@ sub setup_default_spooler {
}
if ($printer->{SPOOLER} ne $oldspooler) {
- # Remove the local printers from Star Office/Open Office
+ # Remove the local printers from Star Office/OpenOffice.org
printer::removelocalprintersfromapplications($printer);
# Get the queues of this spooler